==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dock-network-plugin/translations/dock-network-plugin_kab.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="kab" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Azeḍḍa</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Apṛutukul</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Anaw n tɣellist</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Tasfift</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Abadu</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Agrudem</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tagelmust n uzeṭṭa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tileggit</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS agejdan</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Uzwir</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Arured</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Ibenk yensa</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yeqqen maca ulac adduf ɣer internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ur yeqqin ara</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Agatu n uzeḍḍa yenser</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Tuqqna</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Asesteb</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Awway n tansa n IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Yeqqen</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Yeffeɣ seg tuqqna</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ur yeddi ara</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Azeṭṭa agatwan</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Azeḍḍa s tnelli %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Azeṭṭa war tinelli</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Azeṭṭa war tinelli %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Ibenk yensa</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Agatu n uzeḍḍa yenser</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ur yeqqin ara</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Tuqqna</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yeqqen maca ulac adduf ɣer internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Sens tuqqna n tnelli</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Srmed tuqqna n tnelli</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Sens tuqqna war tinelli</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Sermed tuqqna war tinelli</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Sens azeḍḍa</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Sexsi azeḍḍa</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Iɣewwaren n uzeḍḍa</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dock-network-plugin/translations/dock-network-plugin_kab.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kab">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Azeṭṭa war tinelli</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Azeṭṭa agatwan</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Azeḍḍa</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation>Awal uffir</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Sefsex</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Qqen</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Apṛutukul</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Anaw n tɣellist</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Abadu</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Tasfift</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Agrudem</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tagelmust n uzeṭṭa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tileggit</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS agejdan</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Uzwir</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Arured</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Ibenk yensa</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yeqqen maca ulac adduf ɣer internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ur yeqqin ara</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Agatu n uzeḍḍa yenser</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Tuqqna</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Asesteb</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Awway n tansa n IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Yeqqen</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Yeffeɣ seg tuqqna</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ur yeddi ara</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Azeṭṭa agatwan</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Azeḍḍa s tnelli %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Azeṭṭa war tinelli</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Azeṭṭa war tinelli %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Ibenk yensa</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Agatu n uzeḍḍa yenser</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ur yeqqin ara</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Tuqqna</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yeqqen maca ulac adduf ɣer internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Sens tuqqna n tnelli</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Srmed tuqqna n tnelli</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Sens tuqqna war tinelli</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Sermed tuqqna war tinelli</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Sens azeḍḍa</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Sexsi azeḍḍa</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Iɣewwaren n uzeḍḍa</translation>
    </message>
</context>
</TS>
